@@ -18,13 +18,15 @@ def update_component_to_model(name, version, branch, podfile_model):
                 if isinstance(component, CIComponentModel):
                     podfile_component = component.name.lstrip().split('/')[0]
                     target_component = 'pod %s' % name
-                    if target_component.replace('\'','') == podfile_component.replace('\'',''):
+                    if target_component.replace('\'', '') == podfile_component.replace('\'', ''):
                         if 'https://' in version or 'http://' in version:
                             component.git = f":git => {version}"
-                            component.branch = f":branch => '{branch}'"
+                            component.branch = f":branch => '{branch}'\n"
                         else:
                             component.git = ''
-                            component.version = version
+                            length = len(version)
+                            new_version = version[:length] + '\n' + version[length + 1:]
+                            component.version = new_version
                         exists = True
                         continue
     # 组件在podfile中不存在，添加组件到第一个target中
